@@ -7,9 +7,9 @@
 
 ### ** Examples
 
-data(NIR)
-NIR.pcr <- pcr(y ~ X, 6, data = NIR, CV = TRUE, segments = 10)
-## Not run: plot(MSEP(NIR.pcr))
+data(yarn)
+yarn.pcr <- pcr(density ~ NIR, 6, data = yarn, validation = "CV", segments = 10)
+## Not run: plot(MSEP(yarn.pcr))
 
 
 
