@@ -7,8 +7,8 @@
 
 ### ** Examples
 
-data(NIR)
-nir.mvr <- mvr(y ~ X, ncomp = 8, CV = TRUE, length.seg = 1, data = NIR)
+data(yarn)
+nir.mvr <- mvr(density ~ NIR, ncomp = 8, validation = "LOO", data = yarn)
 nir.mvr
 summary(nir.mvr)
 RMSEP(nir.mvr)
